pub fn format_plain_text_metrics<T: MetricsSnapshotProvider>(
snapshot: &T,
) -> StringExpand description
Formats a metrics snapshot provider into the shared plain-text terminal layout.
pub fn format_plain_text_metrics<T: MetricsSnapshotProvider>(
snapshot: &T,
) -> StringFormats a metrics snapshot provider into the shared plain-text terminal layout.